mlstars.custom.timeseries\_preprocessing.time\_segments\_aggregate
==================================================================

.. currentmodule:: mlstars.custom.timeseries_preprocessing

.. autofunction:: time_segments_aggregate